@@ -7,6 +7,7 @@ import subprocess
 from subprocess import PIPE
 from typing import Optional
 from typing import Tuple
+import warnings
 
 from cryptography import x509
 from cryptography.exceptions import InvalidSignature
@@ -32,6 +33,10 @@ class RevocationChecker:
 
     def __init__(self, enforce_openssl_binary_usage: bool = False) -> None:
         self.broken = False
+        if enforce_openssl_binary_usage:
+            warnings.warn("enforce_openssl_binary_usage parameter is deprecated "
+                "and will be removed in an upcoming certbot major version update",
+                DeprecationWarning)
         self.use_openssl_binary = enforce_openssl_binary_usage
 
         if self.use_openssl_binary:
@@ -234,12 +239,12 @@ def _check_ocsp_response(response_ocsp: 'ocsp.OCSPResponse', request_ocsp: 'ocsp
     # See OpenSSL implementation as a reference:
     # https://github.com/openssl/openssl/blob/ef45aa14c5af024fcb8bef1c9007f3d1c115bd85/crypto/ocsp/ocsp_cl.c#L338-L391
     # thisUpdate/nextUpdate are expressed in UTC/GMT time zone
-    now = datetime.now(pytz.UTC).replace(tzinfo=None)
-    if not response_ocsp.this_update:
+    now = datetime.now(pytz.UTC)
+    if not response_ocsp.this_update_utc:
         raise AssertionError('param thisUpdate is not set.')
-    if response_ocsp.this_update > now + timedelta(minutes=5):
+    if response_ocsp.this_update_utc > now + timedelta(minutes=5):
         raise AssertionError('param thisUpdate is in the future.')
-    if response_ocsp.next_update and response_ocsp.next_update < now - timedelta(minutes=5):
+    if response_ocsp.next_update_utc and response_ocsp.next_update_utc < now - timedelta(minutes=5):
         raise AssertionError('param nextUpdate is in the past.')
 
 
