@@ -3,6 +3,7 @@ import atexit
 from contextlib import ExitStack
 import copy
 from importlib import reload as reload_module
+import importlib.resources
 import io
 import logging
 import multiprocessing
@@ -21,6 +22,7 @@ from typing import Union
 import unittest
 from unittest import mock
 
+from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
@@ -38,11 +40,6 @@ from certbot.compat import os
 from certbot.display import util as display_util
 from certbot.plugins import common
 
-if sys.version_info >= (3, 9):  # pragma: no cover
-    import importlib.resources as importlib_resources
-else:  # pragma: no cover
-    import importlib_resources
-
 
 class DummyInstaller(common.Installer):
     """Dummy installer plugin for test purpose."""
@@ -84,14 +81,14 @@ def vector_path(*names: str) -> str:
     """Path to a test vector."""
     _file_manager = ExitStack()
     atexit.register(_file_manager.close)
-    vector_ref = importlib_resources.files(__package__).joinpath('testdata', *names)
-    path = _file_manager.enter_context(importlib_resources.as_file(vector_ref))
+    vector_ref = importlib.resources.files(__package__).joinpath('testdata', *names)
+    path = _file_manager.enter_context(importlib.resources.as_file(vector_ref))
     return str(path)
 
 
 def load_vector(*names: str) -> bytes:
     """Load contents of a test vector."""
-    vector_ref = importlib_resources.files(__package__).joinpath('testdata', *names)
+    vector_ref = importlib.resources.files(__package__).joinpath('testdata', *names)
     data = vector_ref.read_bytes()
     # Try at most to convert CRLF to LF when data is text
     try:
@@ -102,7 +99,7 @@ def load_vector(*names: str) -> bytes:
         return data
 
 
-def _guess_loader(filename: str, loader_pem: int, loader_der: int) -> int:
+def _guess_loader(filename: str, loader_pem: Callable, loader_der: Callable) -> Callable:
     _, ext = os.path.splitext(filename)
     if ext.lower() == '.pem':
         return loader_pem
@@ -111,43 +108,40 @@ def _guess_loader(filename: str, loader_pem: int, loader_der: int) -> int:
     raise ValueError("Loader could not be recognized based on extension")  # pragma: no cover
 
 
-def load_cert(*names: str) -> crypto.X509:
+def load_cert(*names: str) -> x509.Certificate:
     """Load certificate."""
     loader = _guess_loader(
-        names[-1], crypto.FILETYPE_PEM, crypto.FILETYPE_ASN1)
-    return crypto.load_certificate(loader, load_vector(*names))
+        names[-1], x509.load_pem_x509_certificate, x509.load_der_x509_certificate
+    )
+    return loader(load_vector(*names))
 
 
-def load_csr(*names: str) -> crypto.X509Req:
-    """Load certificate request."""
-    loader = _guess_loader(
-        names[-1], crypto.FILETYPE_PEM, crypto.FILETYPE_ASN1)
-    return crypto.load_certificate_request(loader, load_vector(*names))
+def load_jose_rsa_private_key_pem(*names: str) -> jose.ComparableRSAKey:
+    """Load RSA private key wrapped in jose.ComparableRSAKey"""
+    return jose.ComparableRSAKey(load_rsa_private_key_pem(*names))
 
 
-def load_comparable_csr(*names: str) -> jose.ComparableX509:
-    """Load ComparableX509 certificate request."""
-    return jose.ComparableX509(load_csr(*names))
+def _guess_loader_pyopenssl(filename: str, loader_pem: int, loader_der: int) -> int:
+    # note: used by `load_rsa_private_key_pem`
+    _, ext = os.path.splitext(filename)
+    if ext.lower() == '.pem':
+        return loader_pem
+    elif ext.lower() == '.der':
+        return loader_der
+    raise ValueError("Loader could not be recognized based on extension")  # pragma: no cover
 
 
-def load_rsa_private_key(*names: str) -> jose.ComparableRSAKey:
+def load_rsa_private_key_pem(*names: str) -> RSAPrivateKey:
     """Load RSA private key."""
-    loader = _guess_loader(names[-1], crypto.FILETYPE_PEM, crypto.FILETYPE_ASN1)
+    loader = _guess_loader_pyopenssl(names[-1], crypto.FILETYPE_PEM, crypto.FILETYPE_ASN1)
     loader_fn: Callable[..., Any]
     if loader == crypto.FILETYPE_PEM:
         loader_fn = serialization.load_pem_private_key
     else:
         loader_fn = serialization.load_der_private_key
-    return jose.ComparableRSAKey(
-        cast(RSAPrivateKey,
-             loader_fn(load_vector(*names), password=None, backend=default_backend())))
-
-
-def load_pyopenssl_private_key(*names: str) -> crypto.PKey:
-    """Load pyOpenSSL private key."""
-    loader = _guess_loader(
-        names[-1], crypto.FILETYPE_PEM, crypto.FILETYPE_ASN1)
-    return crypto.load_privatekey(loader, load_vector(*names))
+    key = loader_fn(load_vector(*names), password=None, backend=default_backend())
+    assert isinstance(key, RSAPrivateKey)
+    return key
 
 
 def make_lineage(config_dir: str, testfile: str, ec: bool = True) -> str:
@@ -453,7 +447,7 @@ def lock_and_call(callback: Callable[[], Any], path_to_lock: str) -> None:
     process.start()
 
     # Wait confirmation that lock is acquired
-    assert receive_event.wait(timeout=10), 'Timeout while waiting to acquire the lock.'
+    assert receive_event.wait(timeout=20), 'Timeout while waiting to acquire the lock.'
     # Execute the callback
     callback()
     # Trigger unlock from foreign process
